%%
 %
 % Licensed under Creative Commons Attribution 4.0 International (CC BY 4.0) (the "License").
 % You are free to: 
 %        Share — copy and redistribute the material in any medium or format
 %        Adapt — remix, transform, and build upon the material
 %        for any purpose, even commercially. 
 % Under the following terms:
 %        Attribution — You must give appropriate credit, provide a link to the license, and indicate if changes were made. You may do so in any reasonable manner, but not in any way that suggests the licensor endorses you or your use.
 %        No additional restrictions — You may not apply legal terms or technological measures that legally restrict others from doing anything the license permits.
 % The licensor cannot revoke these freedoms as long as you follow the license terms.
 % You may not use this file except in compliance with the License.
 % You may obtain a copy of the License at
 %
 %      https://creativecommons.org/licenses/by/4.0/legalcode
 %
 % Unless required by applicable law or agreed to in writing, software
 % distributed under the License is distributed on an "AS IS" BASIS,
 % WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 % See the License for the specific language governing permissions and
 % limitations under the License.
%%

function plot_extreme(carpeta, default_sitting, default_standing, margin, n_subplots)
  %% the values of the parameters for the datasets in the supplementary material are:
  %%  carpeta:
  %%    carpeta = "demanding-scenario" for the highly demanding scenario (score > 22) 
  %%    carpeta = "critical-scenario" for the critical scenario (score ~= 17) 
  %% default_sitting = 7 (degrees) for both scenarios
  %% default_standing = 92 (degrees) for both scenarios
  %% margin:
  %%    You can choose the value. The experiments described in the manuscript use margin = 10
  %% n_subplots:
  %%    n_subplots = 1 for plotting the estimation of the thigh angle based on 
  %%  raw acceleration readings.
  %%    n_subplots = 2 for plotting the estimation of the thigh angle based on 
  %%  both raw acceleration readings and gravity components.
  
  n = 0.5 * (length(dir(sprintf("./%s", carpeta))) - 3);
  
  for i=1:n
    acc_filename = sprintf("./%s/accelerometer_%d", carpeta, i);
    accelerometer = load(acc_filename);
    
    g_filename = sprintf("./%s/gravity_%d", carpeta, i);
    gravity = load(g_filename);
    
    fsa = length(accelerometer)/30;
    fsg = length(gravity)/30;
    
    ta = [0:length(accelerometer)-1]/fsa;
    tg = [0:length(gravity)-1]/fsg;
    
    acc_bistable = hysteresis(accelerometer, default_sitting, default_standing, margin);
    g_bistable = hysteresis(gravity, default_sitting, default_standing, margin);
    
    figure(i)
    if n_subplots == 2
      subplot(2,1,1)
    endif
    plot(ta, accelerometer, 'g', ta, acc_bistable, 'r');
    xlabel('Time(s)');
    ylabel('Thigh angle (degrees)');
    axis([0 30 -20 120]);
    
    if n_subplots == 2
      subplot(2,1,2)
      plot(tg, gravity, 'b', tg, g_bistable, 'r');
      xlabel('Time(s)');
      ylabel('Thigh angle (degrees)');
      axis([0 30 -20 120]);
    endif
    
    filename = sprintf("%s/%s/figures/%d_subplots/fig%d.png", pwd, carpeta, n_subplots, i);
    print([filename], "-dpng");
    printf("Señal #%d:\n\tfsa: %.3f\t fsg: %.3f\n\tI have stored the figure at: %s\n", i, fsa, fsg, filename);
  endfor
endfunction
